videocollection/videocollectionwrapper/inc/videocollectionwrapper.h
changeset 62 0e1e938beb1a
parent 46 adbe7d5ba2f5
--- a/videocollection/videocollectionwrapper/inc/videocollectionwrapper.h	Thu Sep 02 20:28:16 2010 +0300
+++ b/videocollection/videocollectionwrapper/inc/videocollectionwrapper.h	Fri Sep 17 08:30:05 2010 +0300
@@ -27,7 +27,7 @@
 
 // FORWARD DECLARATIONS
 class VideoCollectionWrapperPrivate;
-class VideoSortFilterProxyModel;
+class VideoProxyModelGeneric;
 
 
 /**
@@ -39,7 +39,7 @@
  *  @code
  *  #include "videocollectioncommon.h"
  *  #include "videocollectionwrapper.h"
- *  #include "videosortfilterproxymodel.h"
+ *  #include "videoproxymodelgeneric.h"
  *  
  *  ...
  *  ////
@@ -47,7 +47,7 @@
  *  ////
  *  VideoCollectionWrapper &wrapper = VideoCollectionWrapper::instance();
  *  // getting all videos model
- *  VideoSortFilterProxyModel *model = wrapper.getModel(VideoCollectionCommon::EModelTypeAllVideos);
+ *  VideoProxyModelGeneric *model = wrapper.getAllVideosModel();
  *  ...
  *  ////
  *  // Opening collection and start fetching video item data
@@ -80,16 +80,38 @@
     static VideoCollectionWrapper &instance();  
     
 	/**
      * Returns pointer to model. Null if creation fails or if
      * application is closing.
      * 
-     * @param type of the model
+     * @return address to model or NULL if fails or if application is closing.
+     */    
+    VideoProxyModelGeneric* getGenericModel();
+
+    /**
+     * Returns pointer to all videos model. Null if creation fails or if
+     * application is closing.
      * 
      * @return address to model or NULL if fails or if application is closing.
      */    
-    VideoSortFilterProxyModel* getModel(VideoCollectionCommon::TModelType type);
+    VideoProxyModelGeneric* getAllVideosModel();
 
     /**
+     * Returns pointer to collections model. Null if creation fails or if
+     * application is closing.
+     * 
+     * @return address to model or NULL if fails or if application is closing.
+     */    
+    VideoProxyModelGeneric* getCollectionsModel();
+    
+    /**
+     * Returns pointer to collection content model. Null if creation fails or if
+     * application is closing.
+     * 
+     * @return address to model or NULL if fails or if application is closing.
+     */    
+    VideoProxyModelGeneric* getCollectionContentModel();
+    
+    /**
      * Method can be used by client to emit status signal
      * containing status code from particular async status.
      *
@@ -80,16 +80,38 @@
     
 	/**
-     * Returns pointer to model. Null if creation fails or if
+     * Returns pointer to generic video model. Null if creation fails or if
      * application is closing.
      * 